/**
 * 
 */
package uk.co.softwarepulse.fx.view;

import java.util.Optional;

import javafx.application.Platform;
import javafx.fxml.FXML;
import javafx.scene.control.Alert;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.ButtonBar.ButtonData;
import javafx.scene.control.ButtonType;
import javafx.scene.control.ChoiceBox;
import javafx.scene.control.TextArea;
import javafx.scene.control.TextField;
import javafx.scene.control.Tooltip;
import javafx.scene.image.ImageView;
import javafx.stage.Stage;

/**
 * @author jmc
 *
 */
public class ConnectionOverviewController {
	@FXML
	private TextField serverIPField;
    @FXML
    private ChoiceBox<String> modeField;
    @FXML
    private ChoiceBox<String> directionField;
    @FXML
    private TextField fileNameField;
    @FXML
    private TextArea statusField;

    /**
     * Initializes the controller class. This method is automatically called
     * after the fxml file has been loaded.
     */
    @FXML
    private void initialize() {
    	// Set the popup tool tip for the choice field
    	modeField.setTooltip(new Tooltip("Select Ascii if the file is text otherwise use binary"));
    	modeField.getItems().removeAll(modeField.getItems());
    	// Set the options for the field
    	modeField.getItems().addAll("Ascii", "Binary");
    	// By default select an option
    	modeField.getSelectionModel().select("Binary");

    	directionField.setTooltip(new Tooltip("Send (PUT) or receive (GET))file from the server"));
    	directionField.getItems().removeAll(modeField.getItems());
    	directionField.getItems().addAll("GET", "PUT");
    	directionField.getSelectionModel().select("GET");
    	
    	// Set the focus for the cursor to be the first field at the top of the scene
    	// This is set after all the items are configured and rendered.
    	Platform.runLater(new Runnable() {
            @Override
            public void run() {
            	serverIPField.requestFocus();
            }
        });
    }

    
    /**
     * Called when the user clicks clear.
     */
    @FXML
    private void handleClear() {
    	if(isClear2()) {
            serverIPField.setText("");
            modeField.valueProperty().set(null);
            directionField.valueProperty().set(null);
            fileNameField.setText("");
            statusField.clear();
    	}
    }  
    
    /**
     * Called when user clicks 'Clear' button
     * Warns user all fields will be cleared
     * @return
     */
    private boolean isClear() {
    	Boolean clear = false;
    	
        Alert alert = new Alert(AlertType.WARNING);
        alert.setContentText("This is warning alert with an added button for cancel.");
        alert.setTitle("Clear all fields");
        alert.setHeaderText("Are you sure you want to clear all fields?");
        
    	ButtonType cancelButtonType = new ButtonType("Cancel", ButtonData.CANCEL_CLOSE);
        alert.getDialogPane().getButtonTypes().add(cancelButtonType);

        Optional<ButtonType> result = alert.showAndWait();
        if (result.isPresent() && result.get() == ButtonType.OK) {
            clear = true;
        }
		return clear;
	}


    /**
     * Called when user clicks 'Clear' button
     * Warns user all fields will be cleared
     * Uses the AlertType.CONFIRMATION dialog box
     */
    private boolean isClear2() {
    	Boolean clear = false;
    	
        Alert alert = new Alert(AlertType.CONFIRMATION);
        alert.setContentText("This is a confirmation alert with a custom icon.");
        alert.setTitle("Clear all fields");
        alert.setHeaderText("Are you sure you want to clear all fields?");
        
        // Change the icon using in the alert 
        alert.setGraphic(new ImageView(this.getClass().getResource("warning64.gif").toString()));
        
        Optional<ButtonType> result = alert.showAndWait();
        if (result.isPresent() && result.get() == ButtonType.OK) {
            clear = true;
        }
		return clear;
	}
    
    
	/**
     * Called when the user clicks ok.
     */
    @FXML
    private void handleGo() {
        if (isInputValid()) {
        	// Call the TFTP server
            statusField.clear();
        	statusField.appendText("Calling TFTP server...\n");
 
        	statusField.appendText("TFTP server done.\n");
        }

    }


    /**
     * Validates the user input in the text fields.
     * 
     * @return true if the input is valid
     */
    private boolean isInputValid() {
        String errorMessage = "";

        if (serverIPField.getText() == null || serverIPField.getText().length() == 0) {
            errorMessage += "No valid server IP!\n"; 
        }
        if (modeField.getValue() == null ) {
            errorMessage += "No valid mode!\n"; 
        }
        if (directionField.getValue() == null ) {
            errorMessage += "No valid direction!\n"; 
        }

        if (fileNameField.getText() == null || fileNameField.getText().length() == 0) {
            errorMessage += "No valid file name!\n"; 
        }

        if (errorMessage.length() == 0) {
            return true;
        } else {
            // Show the error message.
            Alert alert = new Alert(AlertType.ERROR);
            alert.setTitle("Invalid Fields");
            alert.setHeaderText("Please correct invalid fields");
            alert.setContentText(errorMessage);
            alert.showAndWait();
            return false;
        }
    }

    
    private void hasOptions() {
    	// Show an information dialog with setExpandable and explain this is 
    	// an option from the dialogPane object which is encapsulated within
    	// the Dialog class which Alert extends.
    	
    	/*
    	 * Show an example where headertext is set to null.
    	 */
    	Alert alert = new Alert(AlertType.INFORMATION);
    	
    	// We can also demonstrate an AlertType of NONE.
    	// This is used where none or most of the basic
    	// building blocks are not required.  All of these
    	// will be created from the ground up so rather
    	// than override we create from scratch.
    	// Watch out must have at least one button
    	// to get the code to work.
    	
    }
}
